# Features

## Device Forwarding
* [Audio](Audio.md) : speaker and microphone
* [Printers](Printing.md)
* [Webcams](Webcam.md)
* [Keyboard](Keyboard.md)

## Data Synchronization
* [Clipboard](Clipboard.md)
* [File transfers](File-Transfers.md)
* [System tray](System-Tray.md)
* [Notifications](Notifications.md)

## [Display Characteristics](Display.md)
* [Image Depth](Image-Depth.md)
* [DPI](DPI.md)


## See also
* [platform support](https://github.com/Xpra-org/xpra/wiki/Platforms)
* types of [network connections](../Network/README.md)
* [authentication](../Usage/Authentication.md) and [encryption](../Network/Encryption.md) ([AES](../Network/AES.md), [SSL](../Network/SSL.md))
* [seamless](../Usage/Seamless.md) or [desktop](../Usage/Desktop.md) mode
* [shadow](../Usage/Shadow.md) existing displays
* [proxy server](../Usage/Proxy-Server.md) connection multiplexing
* running as a [system service](../Usage/Service.md)
* [HTML5 client](https://github.com/Xpra-org/xpra-html5)
* session sharing
* advanced automatic [picture encoding](../Usage/Encodings.md)
* hardware acceleration
* superfast shared memory and vsock connections
* [OpenGL accelerated rendering](../Usage/Client-OpenGL.md)
* session broadcast via [mDNS](../Network/Multicast-DNS.md)
